
#!/usr/bin/ksh
#getsysinfo  von S. Stechemesser (HP), BCS Competency Center, 06/2009
export LANG=C
GETSYSINFOVERSION="8.16"
TMPDIR=` mktemp ` # temporary directory
MAXFILESIZE=1024 # Maximum size of some logfile in kbytes
GETFIRSTLINES=512 # if logfiles are truncated, also the first lines are saved
MAXBACKDATE=90  # for some logfiles: get information less then 90 days old
TOMBTIME=180 # tombstone files from last $TOMBILE days are collected
PMANI=0 # do not use print_manifest by default
INITDATA=0 # do not capture initdata stuff by default
SASOPTION=1
NAME=/tmp/sysinfo  #default output name prefix

#better do not change parameters below here unless you know what you are doing
U=`uname`
if [ "T$U" != "THP-UX" ] ; then
   echo "Script is only supported on HP-UX ! - Abort"; exit -1
fi
let MAXFILESIZE=$MAXFILESIZE\*1024
PATH=${PATH}:/usr/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/contrib/bin
PATH=${PATH}:/opt/sas/bin
export PATH
secure=0
tgz=1
diskjn=0
echo "$0 $GETSYSINFOVERSION"
echo "in case of problems run $0 2>&1 | tee getsysinfo.log "
echo "and send this file also to HP"
echo "options: "
echo "-s   : secure, use only non hanging commands"
echo "-t   : (default) make a gzipped tar archive $NAME.tgz (bin)"
echo "-sh  : make shell archive $NAME.shar (ascii)"
echo "-u   : uuencoded tgz file => $NAME.uu (ascii)"
echo "-n   : default filename will be $NAME.hostname.???"
echo "-d   : diskinfo from all disks"
echo "-h   : get all files from /var/tombstones directory instead only those"
echo "     : younger than $TOMBTIME days"
echo "-p   : include information from print_manifest"
echo "-f   : do not truncate some of the logfiles to $MAXFILESIZE kB"
echo "-diag: capture additional data for diagnostics troubleshooting"
echo "-sas : force running of sasmgr\n"
for i in $* ; do
case $i in
-s)
   secure=1
   echo "I will only use normaly non hanging commands ..."
;;
-sh)
   tgz=0
;;
-t)
   tgz=1
;;
-u)
   tgz=2
;;
-n)
H=`hostname`
NAME=$NAME.$H
;;
-f)
   MAXFILESIZE=0  # get full files
;;
-d)
   diskjn=1
;;
-p)
   PMANI=1
;;
-h)
   MAXBACKDATE=10000
   TOMBTIME=10000
   echo "I will collect more information than usual ..."
;;
-diag)
   INITDATA=1
;;
-sas)
   SASOPTION=0 #run sasmgr !
;;
esac
done
OUTFILE="$NAME.shar"
if [ $tgz -eq 1 ] ; then OUTFILE="$NAME.tgz" ; fi
if [ $tgz -eq 2 ] ; then OUTFILE="$NAME.tgz.uu" ; fi
OSVER=`uname -r`
#definition der Funktionen
hw_disk_check() # better version from Stefan Stechemesser MUHW
{
DEVICES=`ioscan -fknCdisk | grep -e /rdsk/ | cut -d "/" -f4`
printf "\n%-24s%-10s%-22s%-8s%-8s%-3s%-3s\n" Hardwarepath Device \
Vendor/Product Cap/GB Firm. QD IR
echo "-----------------------------------------------------------------------\
-------"
for device in $DEVICES
   do
      scsi=`/usr/sbin/scsictl -akq /dev/rdsk/$device 2>/dev/null`
      sir=`echo $scsi|awk -F";" '{ print $1; }{}'`
      sqd=`echo $scsi|awk -F";" '{ print $2; }{}'`
      hw_pfad=` lssf /dev/dsk/$device  | awk '{ print $(NF-1) }'`
      printf "%-24s%-10s" $hw_pfad $device
      (diskinfo -v /dev/rdsk/$device 2> /dev/null \
| grep -e product -e rev -e vendor -e size) |\
awk '{if(match($1,"vendor:")) {vendor=$2}} \
{if (match($1,"product")) {product=$3}} \
{if (match($1,"size:")) {size=$2}} \
{if (match($1,"rev")) {vend_p=vendor"/"product;printf "%-22s%-8.1f%-8s",\
vend_p,(size+0.01)/1024/1024,$3}} '
printf "%-3s%-3s\n" $sqd $sir
done
}
sizefile()
{
# copies only the last FILESIZE bytes of file FILE
 FILE=$1
 FILESIZE=$2
 if [ -f $FILE ] ; then
        FSIZE=` ll $FILE | awk '{print $5}' `
        if [ $FSIZE -gt $FILESIZE -a $FILESIZE -ne 0 ] ; then
           #get first $GETFIRSTLINES lines of file
           echo "WARNING from $0: "
   echo "File $FILE truncated from $FSIZE to $FILESIZE bytes by $0"
           echo "here are the first $GETFIRSTLINES lines of the file:"
           echo "#############################################################"
           head -n $GETFIRSTLINES $FILE
           echo "#############################################################"
           echo "$0: here are the last $FILESIZE bytes of this file"
           echo "#############################################################"
           NBLOCKS=`expr \( $FSIZE - $FILESIZE \) `
           dd if=$FILE bs=1 skip=$NBLOCKS
        else
           cat $FILE
        fi
 else
        echo File $FILE does not exist
 fi
}
copyfiles()
{
#looking for files younger then $MAXBACKDATE days or give back the latest file
  FILE=$1
  DIR=$2
  RESULT=`find  $DIR -mtime -$MAXBACKDATE -a -name ${FILE}\* -a -type f`
  if [ "TEST$RESULT" = "TEST" ] ; then
  RESULT=`ls -rt $DIR/${FILE}* | tail -1`
  fi
  if [ "TEST$RESULT" != "TEST" ] ; then
    cp -p $RESULT $TMPDIR
  fi
}
ex_log()
{ #executes and logs a command
echo $1 ; ( echo "### $1 ###" ; $1 ) >> $TMPDIR/$2
}
mkdir $TMPDIR
if [ $? -ne 0 ] ; then
echo "Could not create directory $TMPDIR - maybe a problem with mktemp - I try a workaround"
TMPDIR=$TMPDIR.sysinfo
mkdir $TMPDIR
if [ $? -ne 0 ] ; then
echo $TMPDIR also failed. please edit script and set TMPDIR manually - Abort.
exit -1
fi
fi
echo "getting system information ..."
/bin/uname -a > $TMPDIR/config
/bin/model >> $TMPDIR/config
SYSTYPE=PA
model | grep -q -E "^ia64"
if [ $? -eq 0 ] ; then
  SYSTYPE=IA64
  ioscanopt=${ioscanopt}e
fi
echo "this is a $SYSTYPE system"
echo "Uptime  and Date:" >> $TMPDIR/config
uptime >> $TMPDIR/config
date >> $TMPDIR/config
echo "$0 version $GETSYSINFOVERSION" >>  $TMPDIR/config
echo $0 options: $* >> $TMPDIR/config
echo "LANG=\"$LANG\""  >> $TMPDIR/config
echo "getting process information..."
ps -ef > $TMPDIR/ps_top.txt
echo "\n\n top -f ps_top.txt -n 128:\n" >> $TMPDIR/ps_top.txt
top -f $TMPDIR/ps_top.txt -d 1 -n 128
if [ $secure -eq 0 ];then
echo CS_MACHINE_SERIAL: `/usr/bin/getconf CS_MACHINE_SERIAL` >> $TMPDIR/config
echo PARTITION_IDENT  : `/usr/bin/getconf PARTITION_IDENT` >> $TMPDIR/config
echo "setboot output:" >> $TMPDIR/config
setboot >> $TMPDIR/config
echo "vgdisplay -v ..." | tee -a  $TMPDIR/config.lvm
vgdisplay -v >> $TMPDIR/config.lvm   2>&1
#begin vxvm output
if [ -x /usr/sbin/vxdctl ] ; then
TMP=`/usr/sbin/vxdctl mode | awk ' { print $2 } '`
if [ "$TMP" != "disabled" -a "$TMP" != "not-running" ] ; then
ex_log "/usr/sbin/vxdctl -c mode" vxvm.txt
ex_log "/usr/sbin/vxdctl license" vxvm.txt
ex_log "/usr/sbin/vxprint -ht" vxvm.txt
ex_log "/usr/sbin/vxdisk list" vxvm.txt
/usr/sbin/vxdisk -e list > /dev/null 2>&1
if [ $? -eq 0 ] ; then
ex_log "/usr/sbin/vxdisk -e list" vxvm.txt
fi
ex_log "/usr/sbin/vxdisk -o alldgs list" vxvm.txt
ex_log "/usr/sbin/vxdisk -s list" vxvm.txt
ex_log "/usr/sbin/vxdg list" vxvm.txt
# the "bootdg" option is new in 4.0
/usr/sbin/vxdg help 2>&1 | grep "bootdg" >> /dev/null
if [ $? -eq 0 ] ; then
ex_log "/usr/sbin/vxdg bootdg" vxvm.txt
fi
for i in `/usr/sbin/vxdg -q list | awk ' { print $1 } '`
do
ex_log "/usr/sbin/vxdg list $i" vxvm.txt
ex_log "/usr/sbin/vxstat -g $i -ffc -d" vxvm.txt
done
fi
fi #end vxvm section
fi
if [ $secure -eq 1 ] ; then
  ioscanopt='k';
fi
ex_log "ioscan -fn$ioscanopt" ioscan.txt
if [ "`uname -r`" = "B.11.31" ] ; then
  ex_log "ioscan -${ioscanopt}m dsf" ioscan.txt
  ex_log "ioscan -${ioscanopt}m lun" ioscan.txt
  ex_log "ioscan -${ioscanopt}m hwpath" ioscan.txt
fi
if [ $secure -eq 0 ];then
echo "getting bootconfig ..."
ex_log "lvlnboot -v" bootconf.txt
cat $TMPDIR/bootconf.txt >> $TMPDIR/config.lvm
for i in `cat $TMPDIR/bootconf.txt | \
awk '{if(match($0,"Boot Disk")){print $1}}' `
do
EFIFS=`echo $i | sed -e "s/p2/p1/" -e "s/s2/s1/"`
(echo "checking bootdisk $i ..."
if [ "X$SYSTYPE" = "XPA" ] ; then
 echo "### lifls -l $i ###"
 lifls -l $i
 echo "### AUTO file of $i ###"
 lifcp $i:AUTO $TMPDIR/AUTO
 cat $TMPDIR/AUTO
fi
if [ "X$SYSTYPE" = "XIA64" ] ; then
 (echo "### EFI Filesystem ###\nefi_ls -d $EFIFS"
  efi_ls -d $EFIFS
 echo efi_ls -d $EFIFS efi
 efi_ls -d $EFIFS efi
 echo efi_ls -d $EFIFS efi/hpux
 efi_ls -d $EFIFS efi/hpux )|  tee $TMPDIR/efils.txt
 efi_cp -d $EFIFS -u efi/hpux/AUTO $TMPDIR
 echo "### contens of AUTO file ###"
 cat $TMPDIR/AUTO
fi
) >>  $TMPDIR/bootconf.txt
 rm $TMPDIR/AUTO
done
fi
(echo
echo "### setboot: ###"
setboot
echo
echo "### Contents of /stand: ###"
ll  /stand/* ) >> $TMPDIR/bootconf.txt
if [ -x /usr/contrib/bin/machinfo ] ; then
/usr/contrib/bin/machinfo > $TMPDIR/machinfo.txt
fi
if [ -x /usr/bin/graphinfo ] ; then
/usr/bin/graphinfo > $TMPDIR/graphinfo.txt  2>&1
fi
if [  -s /var/dt/Xerrors ] ; then
cp -p /var/dt/Xerrors $TMPDIR
fi
#for partitioned systems get partition status
if [ -x /usr/sbin/parstatus ] ; then
   parstatus -s # cellbased ?
   if [ $? -eq 0 ] ; then
   echo "parstatus ..."
   ex_log /usr/sbin/parstatus partition.txt
   for i in `parstatus -C -M | cut -f 2 -d : | \
   sed -e "s/cell//" -e "s/cab//" -e "s/,/\//" `
   do
      ex_log "parstatus -c $i -V" partition.txt
   done
   fi
fi
if [ -x /usr/sbin/vparstatus ] ; then
   echo "vparstatus ..."
   ex_log /usr/sbin/vparstatus partition.txt
   ex_log "/usr/sbin/vparstatus -m"  partition.txt
   ex_log "/usr/sbin/vparstatus -v"  partition.txt
   ex_log "/usr/sbin/vparstatus -e"  partition.txt
fi
VMGUEST=0
model | grep -q -E "Virtual Machine"
if [ $? -eq 0 ] ; then  #virtual machine guest
 VMGUEST=1
 if [ -x /opt/hpvm/bin/hpvminfo ] ; then
 ex_log /opt/hpvm/bin/hpvminfo hpvmstatus.txt
 ex_log "/opt/hpvm/bin/hpvminfo -v" hpvmstatus.txt
 ex_log "/opt/hpvm/bin/hpvminfo -V" hpvmstatus.txt
 VMHOST=`grep Hostname $TMPDIR/hpvmstatus.txt | cut -f 2 -d : `
 fi
else  #not a vm guest
if [ -x /opt/hpvm/bin/hpvmstatus ] ; then
   ex_log "/opt/hpvm/bin/hpvmstatus -v"  hpvmstatus.txt
   ex_log "/opt/hpvm/bin/hpvmnet -v"  hpvmstatus.txt
   ex_log "/opt/hpvm/bin/hpvmstatus -V"  hpvmstatus.txt
   ex_log "/opt/hpvm/bin/hpvmstatus -s"  hpvmstatus.txt
   ex_log "/opt/hpvm/bin/hpvmnet -V"  hpvmstatus.txt
(for i in `hpvmstatus -M | cut -d : -f 1`
do
   echo "\n### Recources for vm $i\n====================== ###\n"
   echo "\nhpvmstatus -P $i -D"
   hpvmstatus -P $i -D
   echo "\n### Logs for vm $i\n====================== ###\n"
   echo "\nhpvmstatus -P $i -r "
   hpvmstatus -P $i -r
   echo "\nhpvmstatus -P $i -i"
   hpvmstatus -P $i -i
   echo "\nhpvmstatus -P $i -e"
   hpvmstatus -P $i -e
done) >> $TMPDIR/hpvmstatus.txt
fi
fi
/etc/dmesg > $TMPDIR/dmesg.txt
ex_log "swlist -l bundle" swlist.txt
echo "_______________________________________" >> $TMPDIR/swlist.txt
ex_log "swlist -l product -a date -a title -a revision" swlist.txt
echo "checking for unconfigured patches ..."
(echo " ### swlist -l fileset -a state | grep -E -v '^#|conf' ###"
swlist -l fileset -a state | grep -E -v '^#|conf' )>>$TMPDIR/swlist.txt
echo "getting lvmtab shutdownlog fstab rc.log syslog and OLDsyslog \
information ..."
ex_log "strings /etc/lvmtab" config.lvm
echo "### fstab: ###" >> $TMPDIR/config.lvm
cat /etc/fstab >> $TMPDIR/config.lvm
if [ -x /usr/sbin/kcmodule ] ; then
(/usr/sbin/kcmodule
/usr/sbin/kctune ) > $TMPDIR/kernelconf.txt
else
cp /stand/system $TMPDIR/kernelconf.txt
fi
what /stand/vmunix >> $TMPDIR/kernelconf.txt
cp -p /etc/shutdownlog $TMPDIR
cp -p /etc/rc.log /etc/rc.log.old $TMPDIR
sizefile /var/adm/syslog/syslog.log   $MAXFILESIZE  > $TMPDIR/syslog.log
sizefile /var/adm/syslog/OLDsyslog.log   $MAXFILESIZE  > $TMPDIR/OLDsyslog.log
echo "getting lan information"
ex_log lanscan  lanconfig.txt
if [ $secure -eq 0 ] ; then
 uname -r | grep -q 11   #not tested for HPUX 10.20
 if [ $? -eq 0 ] ; then
 lanadmin -? 2>&1 | egrep -q "^g "
 if [ $? -eq 0 ] ; then  #only if -g option exists
  F=`perl -n -e 'if(/lan(\d+)/) { print "$1 ";}' $TMPDIR/lanconfig.txt`
  for I in $F
  do
   ex_log "lanadmin -g $I" lanconfig.txt
  done
  ex_log "netstat -rn"  lanconfig.txt
 fi
 fi #end 10.20 test
fi
cat /etc/rc.config.d/netconf >> $TMPDIR/lanconfig.txt
echo /usr/sbin/netfmt /var/adm/nettl.LOG000 ...
/usr/sbin/netfmt /var/adm/nettl.LOG000 > $TMPDIR/nettl.LOG000.txt 2>&1
sizefile $TMPDIR/nettl.LOG000.txt $MAXFILESIZE > $TMPDIR/nettl.txt
rm $TMPDIR/nettl.LOG000.txt
if [ $diskjn -eq 1 ] ; then
 echo getting information about hardisks ...
 hw_disk_check | tee $TMPDIR/diskinfo.txt
fi
if [ $PMANI -eq 1 -a -x /opt/ignite/bin/print_manifest ] ; then
 echo "print_manifest ..."
 /opt/ignite/bin/print_manifest > $TMPDIR/print_manifest.txt
fi
LISTE=`grep -e /dev/fcms -e /dev/td -e /dev/fcd -e /dev/fclp \
$TMPDIR/ioscan.txt |  awk '{printf "%s ", $1}' `
if [ "T$LISTE" != "" ]; then  #we have FC devices
echo getting fibre channel related information
for i in $LISTE
do
echo $i
 DRIVER=`echo $i | cut -d '/' -f 3 | sed 's/[0123456789]//g'`
 FCMSTOOL=${DRIVER}util
 FCMSUTIL=/opt/fcms/bin/$FCMSTOOL
 if [ -x $FCMSUTIL ] ; then
  ex_log "$FCMSUTIL $i" fcmsutil.out
  X=`echo $i | grep fcms`
  if [ "test$X" = "test" ] ; then
   ex_log "$FCMSUTIL $i vpd" fcmsutil.out
  fi
  ex_log "$FCMSUTIL $i stat" fcmsutil.out
 fi
done
if [ $secure -eq 0 ] ; then
for i in td fcd flcp ; do
echo $LISTE | grep -q $i
if [ $? -eq 0 -a -x /opt/fcms/bin/${i}list ] ; then
 ex_log /opt/fcms/bin/${i}list fcmsutil.out
fi
done
fi
fi
if [ -x /usr/sbin/icod_stat ] ; then
   echo "get iCAP info (icod_stat) ..."
   echo "icod_stat:" > $TMPDIR/icod.txt
   /usr/sbin/icod_stat >> $TMPDIR/icod.txt 2>&1
   version=`grep "Software version:" $TMPDIR/icod.txt | awk '{ print $3 }' |\
   cut -d. -f2`
   if [ "Test$version" != "Test" ] ; then
   if [ $version -ge 6 ] ; then
     echo "icod_stat -s:" >> $TMPDIR/icod.txt
     icod_stat -s >> $TMPDIR/icod.txt 2>&1
     if [ -f /var/adm/icod.log ] ; then
        cp -p /var/adm/icod.log $TMPDIR
     fi
   else
     echo "icod_stat -u:" >> $TMPDIR/icod.txt
     icod_stat -u >> $TMPDIR/icod.txt 2>&1
   fi
   fi
fi
if [ -x /usr/sbin/cstm ];then      # does cstm exist ?
CSTMCOMMAND="selall\ninfo\nwait\nil\n\nexit\n\n"
#check regarding known issue with tape backups on HPUX 11.31
echo $OSVER | grep -q -e "11.31"
if [ $? -eq 0 ] ;then # check for known diag problem
DIAGVER=`perl -n -e 'if(/Sup\-Tool\-Mgr.+B\.11\.31\.(\d+)/){print $1;}' < \
$TMPDIR/swlist.txt `
if [ $DIAGVER -lt 6 ] ; then
echo "WARNING : Diag Version < Sep 2009 - no cstm info tool will be started for tapes"
echo "          to prevent possible stop of running backups\n"
CSTMCOMMAND="selall\nuscl type Tape\ninfo\nwait\nil\n\nexit\n\n"
fi
fi
if [ -n `ps -ef | grep -v grep | grep diagmond` ] ; then # is diag running ?
echo "getting diagnostic information. This may take some minutes ..."
echo $CSTMCOMMAND |  /usr/sbin/cstm > $TMPDIR/cstm.info 2>&1
echo "gop cstmpager cat;ru l\nvd\n\nvda\n\n"|/usr/sbin/cstm >$TMPDIR/memlog.txt
fi
if [ -f /var/stm/logs/os/log*.raw* ] ; then
echo get latest logs from logtool ...
LOGFILE=`ll -rt /var/stm/logs/os/log*.raw* | tail -1 | awk ' { print $9 } ' `
cp -p $LOGFILE $TMPDIR/lastlogs.raw
fi
if [ -f /var/stm/logs/os/fpl.log.* ] ; then
echo "writing fpl.log"
copyfiles fpl.log /var/stm/logs/os
fi
if [ -f /var/stm/logs/os/ccerrlog ] ; then
copyfiles ccerrlog /var/stm/logs/os
fi
fi
if [ -f /var/opt/resmon/log/event.log ] ; then
echo "getting EMS event.log file"
copyfiles event.log /var/opt/resmon/log
fi
if [ -f /var/opt/resmon/log/rst.log ] ; then
sizefile /var/opt/resmon/log/rst.log  $MAXFILESIZE  > $TMPDIR/rst.log
fi
#get initdata like information
if [ $INITDATA -eq 1 ] ; then
 echo 'map;wait;lsal;wait;uial;wait;lml;wait;exit' | /usr/sbin/cstm \
 > $TMPDIR/cstm.addinfo
 echo '\n/etc/opt/resmon/lbin/moncheck'
 /etc/opt/resmon/lbin/moncheck > $TMPDIR/moncheck.out
 echo '\n/usr/sbin/psrset'
 /usr/sbin/psrset > $TMPDIR/psrset.out
  if [ -x /opt/wbem/bin/cimprovider ] ; then
   echo '\n/opt/wbem/bin/cimprovider -l -s' | \
   tee $TMPDIR/cimprovider.out
  /opt/wbem/bin/cimprovider -l -s >> $TMPDIR/cimprovider.out
  echo '\n/opt/wbem/bin/cimprovider -lm SFMProviderModule' \
   | tee -a $TMPDIR/cimprovider.out
  /opt/wbem/bin/cimprovider -lm SFMProviderModule >> \
   $TMPDIR/cimprovider.out
  if [ -x /opt/sfm/bin/CIMUtil ] ; then
  echo "The following command is executed twice, pausing two mins. between"
  echo "instances, because it may be building its inventory the first time"
  echo "it's executed on the system"
  echo '\n/opt/sfm/bin/CIMUtil -e root/cimv2 HPUX_Processor'
  /opt/sfm/bin/CIMUtil -e root/cimv2 HPUX_Processor > $TMPDIR/cimutil_proc.out
  echo '\nsleep 120'
  sleep 120
  echo '\n/opt/sfm/bin/CIMUtil -e root/cimv2 HPUX_Processor'
  /opt/sfm/bin/CIMUtil -e root/cimv2 HPUX_Processor > $TMPDIR/cimutil_proc.out
 fi
 fi
 cat $TMPDIR/config > $TMPDIR/initdata
 echo q | /etc/opt/resmon/lbin/monconfig | grep Version >> $TMPDIR/initdata
 echo '\nll /var/opt/resmon/log /etc/opt/resmon/log'
 ll /var/opt/resmon/log /etc/opt/resmon/log >> $TMPDIR/initdata
 tar -cvf $TMPDIR/diagdata.tar -C /var adm/sw/swagent.log opt/resmon/log/rst.log \
 stm/config/tools/monitor/.  stm/data/. stm/logs/. \
 opt/sfmdb/pgsql/sfmdb.log -C /etc hosts inetd.conf services opt/resmon/log/. \
 -C /opt sfm/log/. -C $TMPDIR initdata cstm.addinfo  moncheck.out psrset.out \
 cimutil_proc.out cimprovider.out
 rm $TMPDIR/cstm.addinfo $TMPDIR/moncheck.out  $TMPDIR/initdata \
 $TMPDIR/cimutil_proc.out $TMPDIR/cimprovider.out $TMPDIR/psrset.out
 gzip -9 $TMPDIR/diagdata.tar
fi
#added for possible U320-Adapter
if [ -x /usr/sbin/mptconfig ] ; then
  for i in /dev/mpt*
  do
   if [ -c $i ] ; then
   ( echo ======== $i =======
   mptutil $i
   mptconfig $i )>> $TMPDIR/mpt.out
   fi
  done
fi
#if XP-Diskarray is connected:
if [ $secure -eq 0 ] ; then
 if [ -x /usr/contrib/bin/xpinfo ] ; then
  ex_log /usr/contrib/bin/xpinfo   xpinfo.out
 fi
 #if EVA-Diskarray (active - passive mode) is connected:
 if [ -x /sbin/spmgr ] ; then
  ex_log "/sbin/spmgr display"  spmgr.out
 fi
 #if Diskarray (active - active mode) is connected:
 if [ -x /sbin/autopath ] ; then
  ex_log "/sbin/autopath display" autopath.out
 fi
 #if Raid 4SI Interface is installed
  if [ -x /sbin/irdiag ] ; then
  ex_log "/sbin/irdiag -v" irdiag.out
 fi
 #if raid160 or sa6402 card is installed
 I=`ioscan -fnkd ciss | grep /dev/ciss`
 if [ "Test$I" != "Test" ] ; then
  echo "getting info about SA Raid cards"
  ( echo "ciss devices in ioscan:"
  ioscan -fnkd ciss
  for J in $I
  do
   echo sautil $J
   sautil $J
   echo $J Statistic:
   sautil $J stat
   echo "$J fw_error_log:"
   sautil $J get_fw_err_log
   echo ----------------------------------------------------------
  done) 1> $TMPDIR/sautil.txt 2>&1
 fi
fi  #end secure
#check for SAS devices
I=`grep /dev/sasd $TMPDIR/ioscan.txt`
if [ "Test$I" != "Test" ] ; then
echo "getting information about SAS devices ..."
F=$TMPDIR/sas.txt
P=`grep escsi_ctlr $TMPDIR/ioscan.txt | awk '{print " -e "$3}' `
echo "+ ioscan" > $F
grep $P $TMPDIR/ioscan.txt >> $F
echo "+ ioscan of sas disks" >> $F
grep -i "SAS-" $TMPDIR/swlist.txt >> $F
RUNSAS=$secure
#possible MCA check see emr_na-c01639427-1
grep -q  PHKL_37814 $TMPDIR/swlist.txt
if [ $? -eq 0 ] ; then
 SASVER=`grep "SAS-SASD" $TMPDIR/swlist.txt | awk '{print $2}' `
 SASVER=`echo $SASVER | cut -d '.' -f 4`
 if [ $SASVER -lt 812 ] ; then
  (
  echo "\nWARNING !!! Patch PHKL_37814 is installed, but SAS-SASD revision"
  echo is still $SASVER. Please update at least to B.11.23.0812 !
  echo $0 will not run sasmgr unless the -sas option is given to
  echo "prevent a potential MCA crash.\n") | tee -a $F
  RUNSAS=$SASOPTION
 fi
fi
if [ $RUNSAS -eq 0 ] ; then
echo "running sasmgr ..."
(for sas in $I
do
echo #############################################
echo ++ Information for $sas:
cc="sasmgr get_info -D $sas"
echo + $cc
$cc
for i in vpd smp_addr raid "lun=all -q lun_locate" reg=all
do
echo
echo + $cc -q $i
$cc  -q $i
done
for i in phy=all target=all phy_in_port=all
do
echo; echo + $cc -q $i
$cc -q $i
echo + sasmgr get_stat -D $sas -q $i
sasmgr get_stat -D $sas -q $i
done
echo + sasmgr get_stat -D $sas
sasmgr get_stat -D $sas
done) >> $F
fi
echo "getting file /stand/krs/system.krs"
cp -p /stand/krs/system.krs $TMPDIR/system.krs
fi
#/var/tombstones
mkdir $TMPDIR/tombstones
if [ -d /var/tombstones ] ; then
cd /var/tombstones
if [ $? -eq 0 ] ; then
echo getting tombstones from last $TOMBTIME days ...
ll > $TMPDIR/tombstones/ll.txt
find . -mtime -$TOMBTIME -type f  | cpio -pvdlmx $TMPDIR/tombstones
fi
fi
if [ -f $TMPDIR/efils.txt ] ; then
 grep -i -e efi_ls -e mca -e err $TMPDIR/efils.txt | \
 perl -n -e "if(/efi_ls -d \S+\s+(\S+)/){\$p=\$1.'/';}" \
 -e "if(/(\S+)\s+(\d+\/\d+\/\d+)/){\$fn=\$p.\$1;\$fo=\$2;\$fo=~s/\//\./g;" \
 -e "\$fo=\$fn.'.'.\$fo;\$fo=~s/\//_/g;" \
 -e "\$cm=\"efi_cp -d $EFIFS -u \".\$fn.\" $TMPDIR/tombstones/\".\$fo;" \
 -e " print \$cm,'  '; system(\$cm);}"
 mv $TMPDIR/efils.txt $TMPDIR/tombstones/efils.txt
fi
#list crash directory
ll /var/adm/crash/* > $TMPDIR/crash.ll.txt
crashconf >> $TMPDIR/crash.ll.txt
echo $OSVER | grep -q -e "11.23" -e "11.31"
if [ $? -eq 0 ] ; then #only for these OS versions
if [ -x /opt/sfm/bin/sfmconfig ] ; then # system fault manager
echo "sfmconfig"
/opt/sfm/bin/sfmconfig -w -q > $TMPDIR/sfmconfig.txt
grep -q -e "SysFaultMgmt is monitoring devices" $TMPDIR/sfmconfig.txt
if [ $? -eq 0 ] ; then  #capture sfmlogs
  ex_log "evweb eventviewer -L -x -f -a $MAXBACKDATE:dd" sfmlog.txt
fi
fi
fi
#finally make a compressed shar archive of the system
jn="n"
while [ -f $OUTFILE -a $jn != "y" ];do
echo "overwrite file $OUTFILE ? (y/n)" 1>&2
read jn
if [ $jn != "y" ];then
echo "please enter new full pathname " 1>&2
read OUTFILE
jn="y"
fi
echo $jn
done
echo "writing system info to $OUTFILE ..."
cd $TMPDIR
case $tgz in
0)
shar -c -Z -u * > $OUTFILE ;;
1)
tar -cvf - * | gzip -9 -c > $OUTFILE ;;
2)
tar -cvf - * | gzip -9 -c | uuencode sysinfo.tgz > $OUTFILE ;;
esac
echo cleaning up ...
# for security no  rm -r or rm * !!!
for i in config ioscan.txt dmesg.txt swlist.txt syslog.log cstm.info \
rc.log* lastlogs.raw OLDsyslog.log diskinfo.txt fcmsutil.out ccerrlog* \
event.log* rst.log  partition.txt config.lvm shutdownlog irdiag.out sas.txt \
spmgr.out xpinfo.out fpl.log.* memlog.txt machinfo.txt graphinfo.txt nettl.txt \
mpt.out sautil.txt kernelconf.txt Xerrors icod.* ps_top.txt print_manifest.txt \
bootconf.txt crash.ll.txt autopath.out diagdata.tar vxvm.txt sfmconfig.txt \
hpvmstatus.txt system.krs sfmlog.txt lanconfig.txt
do  # to avoid errors regarding missing files
  if [ -f $i ] ; then
     rm $i
  fi
done
if [ -d tombstones ] ; then
rm -r tombstones
fi
cd /tmp
rmdir $TMPDIR
echo "sysinfo successfully written to $OUTFILE."
if [ $tgz -eq 1 ] ; then
echo "ATTENTION: $OUTFILE is a binary file. Transfer it in binary mode"
echo "via ftp or mail. You can use the -u or -sh option to create ascii output."
fi
#Virtual Machine reminder
if [ $VMGUEST -eq 1 ] ; then
echo "!!! This is a Virtual Machine Client !!!"
echo "Please do not forget to also capture the sysinfo.tgz from the VM Host"
echo $VMHOST !
fi